1. Install Anaconda

2. run "conda create -n seisloc python=3.7"

3. run "conda activate seisloc"

4. run "pip install seisloc"

5. 'cd example'

6. 'jupyter notebook'

7. download EQTransofmer "https://github.com/smousavi05/EQTransformer.git" for more detail

This is a tool package for raw data processing. Developed by Jinping ZI from CUHK Seismology Lab.

